@@ -107,6 +107,8 @@ zpowerall<-tabled-abs(zall)
 powerab1<-round(1-stats::pnorm(zpowerab1),4)
 powerab2<-round(1-stats::pnorm(zpowerab2),4)
 powerall<-round(1-stats::pnorm(zpowerall),4)
+message("Use these results if you plan to use the Sobel test (not recommended)")
+message("Consider the medjs function (recommended) for most applications")
 message("Power for n = ", n,", mediator 1", " is ", powerab1)
 message("Power for n = ", n,", mediator 2", " is ", powerab2)
 message("Power for n = ",n,", Total Mediation", " is ", powerall)
@@ -169,6 +171,8 @@ else if(mvars==3){
   powerab2<-round(1-stats::pnorm(zpowerab2),4)
   powerab3<-round(1-stats::pnorm(zpowerab3),4)
   powerall<-round(1-stats::pnorm(zpowerall),4)
+  message("Use these results if you plan to use the Sobel test (not recommended)")
+  message("Consider the medjs function (recommended) for most applications")
   message("Power for n = ", n,", mediator 1", " is ", powerab1)
   message("Power for n = ", n,", mediator 2", " is ", powerab2)
   message("Power for n =", n,", mediator 3", " is ", powerab3)
@@ -243,6 +247,8 @@ else if(mvars==3){
     powerab3<-round(1-stats::pnorm(zpowerab3),4)
     powerab4<-round(1-stats::pnorm(zpowerab4),4)
     powerall<-round(1-stats::pnorm(zpowerall),4)
+    message("Use these results if you plan to use the Sobel test (not recommended)")
+    message("Consider the medjs function (recommended) for most applications")
     message("Power for n = ", n,", mediator 1", " is ", powerab1)
     message("Power for n = ", n,", mediator 2", " is ", powerab2)
     message("Power for n = ", n,", mediator 3", " is ", powerab3)
